@@ -109,6 +109,9 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	gchar *call, *countstr, *str;
 	gint c;
 
+#define CQ 13
+#define SP 14
+ 
 	if (keyerwindow)
 	switch (event->keyval)
 	{
@@ -167,19 +170,20 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	case GDK_Return:
 		myrstentry = lookup_widget (mainwindow, "myrstentry");
 		callentry = lookup_widget (mainwindow, "callentry");
-		if (GTK_WIDGET_HAS_FOCUS (myrstentry))
+		if (gtk_widget_has_focus (myrstentry))
 		{
 			if (keyerstate.cqmode)
-				cw (NULL, "cq");
+				cw (NULL, GINT_TO_POINTER(CQ));
 			else
-				cw (NULL, "sp");
+				cw (NULL, GINT_TO_POINTER(SP));
 			clickallmenu = gtk_ui_manager_get_widget
 				(ui_manager, "/MainMenu/EditMenu/Click All");
 			g_signal_emit_by_name (G_OBJECT (clickallmenu), "activate");
-			abutton = gtk_ui_manager_get_widget (ui_manager, "/ToolBar/Add");
-			g_signal_emit_by_name (G_OBJECT (abutton), "clicked");
+			abutton = gtk_ui_manager_get_widget (ui_manager,
+				"/MainMenu/EditMenu/Write");
+			g_signal_emit_by_name (G_OBJECT (abutton), "activate");
 		}
-		else if (GTK_WIDGET_HAS_FOCUS (callentry))
+		else if (gtk_widget_has_focus (callentry))
 		{
 			rstentry = lookup_widget (mainwindow, "rstentry");
 			call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
@@ -229,7 +233,7 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 			else
 			{
 				if (keyerstate.cqmode)
-				{	/* call CQ */
+				{	/* call CQ */ 
 					f1button = lookup_widget (keyerwindow, "f1button");
 					gtk_widget_activate (f1button);
 				}
@@ -288,6 +292,14 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 			else
 				return FALSE;
 		break;
+		case GDK_Return:
+			callentry = lookup_widget (mainwindow, "callentry");
+			if (gtk_widget_has_focus(callentry))
+			{
+				rstentry = lookup_widget (mainwindow, "rstentry");
+				gtk_widget_grab_focus (rstentry);
+			}
+		break;
 		default:
 		return FALSE;
 		break;
