@@ -185,7 +185,7 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_free (temp);
 
 	locatorframe = lookup_widget (scorewindow, "locatorframe");
-	if (GTK_WIDGET_VISIBLE (locatorframe))
+	if (gtk_widget_get_visible (locatorframe))
 	{
 		framelabel = gtk_frame_get_label_widget (GTK_FRAME(locatorframe));
 		gtk_label_set_text (GTK_LABEL (framelabel), _("Locator"));
@@ -226,7 +226,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*powerentry, *endentry, *callentry, *count, *awardsentry,
 		*bandoptionmenu, *modeoptionmenu;
 	GtkTextBuffer *b;
-	guint c, bandenum, modeenum;
+	gint c, bandenum, modeenum;
 	gchar *countstr, *lastmsg, *str;
 	GtkWidget *mhzbutton, *modebutton, *rstbutton, *powerbutton;
 
@@ -235,7 +235,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_signal_emit_by_name (G_OBJECT (datebutton), "clicked");
 	g_signal_emit_by_name (G_OBJECT (gmtbutton), "clicked");
 	endhbox = lookup_widget (mainwindow, "endhbox");
-	if (GTK_WIDGET_VISIBLE (endhbox))
+	if (gtk_widget_get_visible (endhbox))
 	{
 		endentry = lookup_widget (mainwindow, "endentry");
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1)) == 0)
@@ -274,7 +274,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 			rstbutton = lookup_widget (mainwindow, "rstbutton");
 			g_signal_emit_by_name (G_OBJECT (rstbutton), "clicked");
 		}
-		if (GTK_WIDGET_VISIBLE (powerhbox))
+		if (gtk_widget_get_visible (powerhbox))
 		{
 			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1)) == 0)
 			{
@@ -290,8 +290,9 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
  			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1)) == 0)
  				gtk_entry_set_text (GTK_ENTRY (bandentry), preferences.defaultmhz);
 			bandenum = freq2enum (preferences.defaultmhz);
+			if (bandenum >= 0)
 			activate_bandoption_by_enum
-                                (bandoptionmenu, preferences.bands, bandenum);
+				(bandoptionmenu, preferences.bands, bandenum);
 		}
  		if (strlen (preferences.defaultmode) > 0)
 		{
@@ -331,7 +332,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 				else
 					gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
 			}
-		if (GTK_WIDGET_VISIBLE (powerhbox) && strlen (preferences.defaultpower) > 0)
+		if (gtk_widget_get_visible (powerhbox) && strlen (preferences.defaultpower) > 0)
 		{
 			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1)) == 0)
 				gtk_entry_set_text (GTK_ENTRY (powerentry), preferences.defaultpower);
@@ -352,21 +353,21 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_entry_set_text (GTK_ENTRY (awardsentry), preferences.defaultawards);
 	}
 	unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
-	if (GTK_WIDGET_VISIBLE (unknown1hbox)	&& strlen (preferences.defaultfreefield1) > 0)
+	if (gtk_widget_get_visible (unknown1hbox)	&& strlen (preferences.defaultfreefield1) > 0)
 	{
 		unknownentry1 = lookup_widget (mainwindow, "unknownentry1");
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (unknownentry1), 0, -1)) == 0)
 			gtk_entry_set_text (GTK_ENTRY (unknownentry1), preferences.defaultfreefield1);
 	}
 	unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
-	if (GTK_WIDGET_VISIBLE (unknown2hbox)	&& strlen (preferences.defaultfreefield2) > 0)
+	if (gtk_widget_get_visible (unknown2hbox)	&& strlen (preferences.defaultfreefield2) > 0)
 	{
 		unknownentry2 = lookup_widget (mainwindow, "unknownentry2");
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (unknownentry2), 0, -1)) == 0)
 			gtk_entry_set_text (GTK_ENTRY (unknownentry2), preferences.defaultfreefield2);
 	}
 	remarksvbox = lookup_widget (mainwindow, "remarksvbox");
-	if (GTK_WIDGET_VISIBLE (remarksvbox) && strlen (preferences.defaultremarks) > 0)
+	if (gtk_widget_get_visible (remarksvbox) && strlen (preferences.defaultremarks) > 0)
 	{
 		remtv = lookup_widget (mainwindow, "remtv");
 		b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
