@@ -220,7 +220,7 @@ config_create (void)
 	preferences.awardswaz = 0;
 	preferences.awardsiota = 0;
 	preferences.awardsloc = 0;
-	preferences.openurl = g_strdup ("http://www.qrz.com/<call>");
+	preferences.openurl = g_strdup ("http://www.qrz.com/db/<call>");
 	preferences.initlastmsg = g_strdup ("");
 }
 
@@ -353,7 +353,7 @@ static void config_load_from_keyfile (GKeyFile *file)
 		preferences.distqrb = preferences.distqrb - 1;
 	preferences.openurl = g_key_file_get_string (file, "general", "openurl", NULL);
 	if (!preferences.openurl)
-		preferences.openurl = g_strdup ("http://www.qrz.com/<call>");
+		preferences.openurl = g_strdup ("http://www.qrz.com/db/<call>");
 
 	preferences.viewscoring = g_key_file_get_integer (file, "appearance", "viewscoring", NULL);
 	if (preferences.viewscoring == 0)
