@@ -1260,7 +1260,7 @@ void fill_scoring_arrays (void)
 			else
 				lookup = lookupcountry_by_callsign (call);
 
-			if (preferences.scoringbands[f] == 1)
+			if (f >= 0 && preferences.scoringbands[f] == 1)
 			{
 				qslconfirmed = qslreceived (qslin);
 				if (lookup.country > 0)
