@@ -40,7 +40,7 @@ extern gushort dxcc_c[400][MAX_BANDS + 1];
 
 void on_awards_dxcc_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	if (!GTK_WIDGET_VISIBLE(scorewindow))
+	if (!gtk_widget_get_visible(scorewindow))
 		warningdialog (_("xlog - DXCC award"),
 			_("Please enable the scoring window"), "gtk-dialog-warning");
 	GtkWidget *dialog = gtk_dialog_new_with_buttons (_("xlog - DXCC award"),
