@@ -62,7 +62,7 @@ static int num_compar(const void *a, const void *b)
 /* create a boring locator scoring list */
 void on_awards_locator_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	if (!GTK_WIDGET_VISIBLE(scorewindow))
+	if (!gtk_widget_get_visible(scorewindow))
 		warningdialog (_("xlog - locator list"),
 			_("Please enable the scoring window"), "gtk-dialog-warning");
 	if (preferences.awardsloc == 0)
@@ -440,7 +440,7 @@ map_configure (GtkWidget *da, GdkEventConfigure *event, gpointer data)
 	gdk_draw_rectangle(pm, da->style->white_gc,	TRUE, 0, 0,
 		da->allocation.width, da->allocation.height);
 	draw_locator_scoring (da, pm, i);
-	gdk_draw_drawable(da->window, da->style->fg_gc[GTK_WIDGET_STATE(da)],
+	gdk_draw_drawable(da->window, da->style->fg_gc[gtk_widget_get_state(da)],
 		pm,	da->allocation.x, da->allocation.y,
 		da->allocation.x, da->allocation.y,
 		da->allocation.width, da->allocation.height);
@@ -451,7 +451,7 @@ static gboolean
 map_expose (GtkWidget *da, GdkEventExpose *event, gpointer data)
 {
 	if (pm) gdk_draw_drawable
-		(da->window, da->style->fg_gc[GTK_WIDGET_STATE(da)], pm,
+		(da->window, da->style->fg_gc[gtk_widget_get_state(da)], pm,
 		event->area.x, event->area.y, event->area.x, event->area.y,
 		event->area.width, event->area.height);
 	return FALSE;
@@ -508,7 +508,7 @@ motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
 
 void on_awards_locatormap_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	if (!GTK_WIDGET_VISIBLE(scorewindow))
+	if (!gtk_widget_get_visible(scorewindow))
 		warningdialog (_("xlog - locator map"),
 			_("Please enable the scoring window"), "gtk-dialog-warning");
 	if (preferences.awardsloc == 0)
