@@ -37,7 +37,7 @@ extern gushort wac_c[MAX_CONTINENTS][MAX_BANDS + 1];
 
 void on_awards_wac_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	if (!GTK_WIDGET_VISIBLE(scorewindow))
+	if (!gtk_widget_get_visible(scorewindow))
 		warningdialog (_("xlog - WAC award"),
 			_("Please enable the scoring window"), "gtk-dialog-warning");
 	if (preferences.awardswac == 0)
