@@ -65,12 +65,10 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	gboolean check;
 	gchar *temp;
 	GtkTreeViewColumn *column;
-	GtkTreeIter iter;
-	gint i, j, response;
-	gchar iter_num[2] = "1";
+	gint i, response;
 
 	dialogsdialog = gtk_dialog_new_with_buttons (_("xlog - dialogs and windows"),
-		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 	notebook = gtk_notebook_new ();
@@ -635,34 +633,27 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb29));
 		preferences.scoringbands[BAND_SUBMM] = check ? 1 : 0;
 
+		/* update the scoring window */
+		GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+		notebook_remove_dxccpage (scorewindow, awardsnotebook);
+		notebook_append_dxccpage (scorewindow, awardsnotebook);
+		fill_scoring_arrays ();
+		update_dxccscoring ();
+
 		/* WAC */
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bwac));
 		if (check)
 		{
-			if (preferences.awardswac == 0)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				notebook_append_wacpage (scorewindow, awardsnotebook);
-				fill_scoring_arrays ();
-				update_wacscoring ();
-			}
+			if (preferences.awardswac == 1)
+				notebook_remove_wacpage (scorewindow, awardsnotebook);
+			notebook_append_wacpage (scorewindow, awardsnotebook);
+			update_wacscoring ();
 			preferences.awardswac = 1;
 		}
 		else
 		{
 			if (preferences.awardswac == 1)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				GtkWidget *scrolledwindow2 = lookup_widget (scorewindow, "scrolledwindow2");
-				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
-					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow2));
-				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
-				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
-				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
-				iter_num[0]++;
-				for (j = 0; j < MAX_BANDS + 1; j++)
-					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
-			}
+				notebook_remove_wacpage (scorewindow, awardsnotebook);
 			preferences.awardswac = 0;
 		}
 
@@ -670,30 +661,16 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bwas));
 		if (check)
 		{
-			if (preferences.awardswas == 0)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				notebook_append_waspage (scorewindow, awardsnotebook);
-				fill_scoring_arrays ();
-				update_wasscoring ();
-			}
+			if (preferences.awardswas == 1)
+				notebook_remove_waspage (scorewindow, awardsnotebook);
+			notebook_append_waspage (scorewindow, awardsnotebook);
+			update_wasscoring ();
 			preferences.awardswas = 1;
 		}
 		else
 		{
 			if (preferences.awardswas == 1)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				GtkWidget *scrolledwindow3 = lookup_widget (scorewindow, "scrolledwindow3");
-				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
-					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow3));
-				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
-				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
-				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
-				iter_num[0]++;
-				for (j = 0; j < MAX_BANDS + 1; j++)
-					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
-			}
+				notebook_remove_waspage (scorewindow, awardsnotebook);
 			preferences.awardswas = 0;
 		}
 
@@ -701,30 +678,16 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bwaz));
 		if (check)
 		{
-			if (preferences.awardswaz == 0)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				notebook_append_wazpage (scorewindow, awardsnotebook);
-				fill_scoring_arrays ();
-				update_wazscoring ();
-			}
+			if (preferences.awardswaz == 1)
+				notebook_remove_wazpage (scorewindow, awardsnotebook);
+			notebook_append_wazpage (scorewindow, awardsnotebook);
+			update_wazscoring ();
 			preferences.awardswaz = 1;
 		}
 		else
 		{
 			if (preferences.awardswaz == 1)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				GtkWidget *scrolledwindow4 = lookup_widget (scorewindow, "scrolledwindow4");
-				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
-					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow4));
-				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
-				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
-				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
-				iter_num[0]++;
-				for (j = 0; j < MAX_BANDS + 1; j++)
-					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
-			}
+				notebook_remove_wazpage (scorewindow, awardsnotebook);
 			preferences.awardswaz = 0;
 		}
 
@@ -732,30 +695,16 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(biota));
 		if (check)
 		{
-			if (preferences.awardsiota == 0)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				notebook_append_iotapage (scorewindow, awardsnotebook);
-				fill_scoring_arrays ();
-				update_iotascoring ();
-			}
+			if (preferences.awardsiota == 1)
+				notebook_remove_iotapage (scorewindow, awardsnotebook);
+			notebook_append_iotapage (scorewindow, awardsnotebook);
+			update_iotascoring ();
 			preferences.awardsiota = 1;
 		}
 		else
 		{
 			if (preferences.awardsiota == 1)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				GtkWidget *scrolledwindow5 = lookup_widget (scorewindow, "scrolledwindow5");
-				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
-					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow5));
-				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
-				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
-				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
-				iter_num[0]++;
-				for (j = 0; j < MAX_BANDS + 1; j++)
-					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
-			}
+				notebook_remove_iotapage (scorewindow, awardsnotebook);
 			preferences.awardsiota = 0;
 		}
 
@@ -763,29 +712,17 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bloc));
 		if (check)
 		{
-			if (preferences.awardsloc == 0)
-			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				notebook_append_locpage (scorewindow, awardsnotebook);
-				fill_scoring_arrays ();
-				update_locscoring ();
-			}
+			if (preferences.awardsloc == 1)
+				notebook_remove_locpage (scorewindow, awardsnotebook);
+			notebook_append_locpage (scorewindow, awardsnotebook);
+			update_locscoring ();
 			preferences.awardsloc = 1;
 		}
 		else
 		{
 			if (preferences.awardsloc == 1)
 			{
-				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
-				GtkWidget *scrolledwindow6 = lookup_widget (scorewindow, "scrolledwindow6");
-				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
-					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow6));
-				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
-				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
-				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
-				iter_num[0]++;
-				for (j = 0; j < MAX_BANDS + 1; j++)
-					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
+				notebook_remove_locpage (scorewindow, awardsnotebook);
 				if (locatormap)
 				{
 					gtk_widget_destroy (locatormap);
