@@ -221,7 +221,7 @@ on_wizard_close_clicked (GtkAssistant *assistant, gpointer user_data)
 			set_qsoframe (logw);
 			set_tabs_menu ();
 
-			if (GTK_WIDGET_VISIBLE(scorewindow))
+			if (gtk_widget_get_visible(scorewindow))
 			{
 				fill_scoring_arrays ();
 				update_dxccscoring ();
