@@ -435,7 +435,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	radiobutton = gtk_button_new_with_mnemonic (_("_Select a Radio"));
 	gtk_box_pack_start (GTK_BOX (radiohbox), radiobutton, TRUE, TRUE, 0);
 	gtk_editable_set_editable (GTK_EDITABLE (radioentry), FALSE);
-	GTK_WIDGET_UNSET_FLAGS (GTK_EDITABLE (radioentry), GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (GTK_WIDGET (radioentry), FALSE);
 
 	devicehbox = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hamlibvbox), devicehbox, FALSE, FALSE, 0);
@@ -510,8 +510,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "3000");
 	gtk_editable_set_editable
 		(GTK_EDITABLE (GTK_BIN(pollcombo)->child), FALSE);
-	GTK_WIDGET_UNSET_FLAGS
-		(GTK_EDITABLE (GTK_BIN(pollcombo)->child), GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus
+		(GTK_WIDGET (GTK_BIN(pollcombo)->child), FALSE);
 	gtk_widget_set_size_request (pollcombo, 100, -1);
 	secondslabel = gtk_label_new (_("milliseconds"));
 	gtk_box_pack_start (GTK_BOX (pollinghbox), secondslabel, FALSE, FALSE, 0);
@@ -542,8 +542,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (digitscombo), "5");
 	gtk_editable_set_editable
 		(GTK_EDITABLE (GTK_BIN(digitscombo)->child), FALSE);
-	GTK_WIDGET_UNSET_FLAGS
-		(GTK_EDITABLE (GTK_BIN(digitscombo)->child), GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus
+		(GTK_WIDGET (GTK_BIN(digitscombo)->child), FALSE);
 	gtk_widget_set_size_request (digitscombo, 100, -1);
 	characterslabel = gtk_label_new ("(0 = 1 Hz, 1 = 10 Hz, ...)");
 	gtk_box_pack_start (GTK_BOX (digitshbox), characterslabel, FALSE, FALSE, 0);
@@ -571,7 +571,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	pathentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (pathhbox), pathentry, TRUE, TRUE, 0);
 	gtk_editable_set_editable (GTK_EDITABLE (pathentry), FALSE);
-	GTK_WIDGET_UNSET_FLAGS (pathentry, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (pathentry, FALSE);
 	pathbutton = gtk_button_new_from_stock (GTK_STOCK_OPEN);
 	gtk_widget_set_size_request (pathbutton, 100, -1);
 	gtk_box_pack_start (GTK_BOX (pathhbox), pathbutton, FALSE, FALSE, 0);
@@ -605,8 +605,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (ordercombo), _("Alphabet"));
 	gtk_editable_set_editable
 		(GTK_EDITABLE (GTK_BIN(ordercombo)->child), FALSE);
-	GTK_WIDGET_UNSET_FLAGS
-		(GTK_EDITABLE (GTK_BIN(ordercombo)->child), GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus
+		(GTK_WIDGET (GTK_BIN(ordercombo)->child), FALSE);
 
 	savingframe = gtk_frame_new (_("Saving"));
 	gtk_box_pack_start (GTK_BOX (vboxpage5), savingframe, FALSE, FALSE, 0);
@@ -644,8 +644,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "120");
 	gtk_editable_set_editable
 		(GTK_EDITABLE (GTK_BIN(autosavecombo)->child), FALSE);
-	GTK_WIDGET_UNSET_FLAGS
-		(GTK_EDITABLE (GTK_BIN(autosavecombo)->child), GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus
+		(GTK_WIDGET (GTK_BIN(autosavecombo)->child), FALSE);
 	gtk_widget_set_size_request (autosavecombo, 100, -1);
 	minuteslabel = gtk_label_new (_("minutes"));
 	gtk_box_pack_start (GTK_BOX (autosavehbox), minuteslabel, FALSE, FALSE, 0);
@@ -672,7 +672,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	backupentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (backuphbox), backupentry, TRUE, TRUE, 0);
 	gtk_editable_set_editable (GTK_EDITABLE (backupentry), FALSE);
-	GTK_WIDGET_UNSET_FLAGS (backupentry, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (backupentry, FALSE);
 	backupbutton = gtk_button_new_from_stock (GTK_STOCK_OPEN);
 	gtk_widget_set_size_request (backupbutton, 100, -1);
 	gtk_box_pack_start (GTK_BOX (backuphbox), backupbutton, FALSE, FALSE, 0);
@@ -692,7 +692,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	fontentry = gtk_entry_new (); 	 
 	gtk_box_pack_start (GTK_BOX (fonthbox), fontentry, TRUE, TRUE, 10); 	 
 	gtk_editable_set_editable (GTK_EDITABLE (fontentry), FALSE); 	 
-	GTK_WIDGET_UNSET_FLAGS (fontentry, GTK_CAN_FOCUS); 	 
+	gtk_widget_set_can_focus (fontentry, FALSE); 	 
 	fontbutton = gtk_button_new_from_stock (GTK_STOCK_SELECT_FONT); 	 
 	gtk_widget_set_size_request (fontbutton, 100, -1); 	 
 	gtk_box_pack_start (GTK_BOX (fonthbox), fontbutton, FALSE, FALSE, 0);
