@@ -51,6 +51,14 @@ on_scorewindow_delete_event (GtkWidget * widget, GdkEvent * event,	gpointer user
 	return TRUE;		/* do not destroy */
 }
 
+static void
+notebook_remove_awardpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook, const gchar *windowname)
+{
+	GtkWidget *scrolledwindow = lookup_widget (scorewindow, windowname);
+	gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
+		gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow));
+}
+
 static void
 notebook_append_awardpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook, const gchar *treeviewname, const gchar *tabname, const gchar *windowname)
 {
@@ -267,18 +275,21 @@ notebook_append_awardpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook, co
 		(GTK_NOTEBOOK(awardsnotebook), scrolledwindow, tablabel);
 
 	GLADE_HOOKUP_OBJECT (scorewindow, awardtreeview, treeviewname);
-
-	if (windowname)
-	{
-		gtk_widget_show_all (scrolledwindow);
-		GLADE_HOOKUP_OBJECT (scorewindow, scrolledwindow, windowname);
-	}
+	GLADE_HOOKUP_OBJECT (scorewindow, scrolledwindow, windowname);
+	gtk_widget_show_all (scrolledwindow);
 }
 
-static void
+
+void
 notebook_append_dxccpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
 {
-	notebook_append_awardpage (scorewindow, awardsnotebook, "dxcctreeview", "DXCC", NULL);
+	notebook_append_awardpage (scorewindow, awardsnotebook, "dxcctreeview", "DXCC", "scrolledwindow1");
+}
+
+void
+notebook_remove_dxccpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_remove_awardpage (scorewindow, awardsnotebook, "scrolledwindow1");
 }
 
 void
@@ -287,30 +298,60 @@ notebook_append_wacpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
 	notebook_append_awardpage (scorewindow, awardsnotebook, "wactreeview", "WAC", "scrolledwindow2");
 }
 
+void
+notebook_remove_wacpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_remove_awardpage (scorewindow, awardsnotebook, "scrolledwindow2");
+}
+
 void
 notebook_append_waspage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
 {
 	notebook_append_awardpage (scorewindow, awardsnotebook, "wastreeview", "WAS", "scrolledwindow3");
 }
 
+void
+notebook_remove_waspage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_remove_awardpage (scorewindow, awardsnotebook, "scrolledwindow3");
+}
+
 void
 notebook_append_wazpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
 {
 	notebook_append_awardpage (scorewindow, awardsnotebook, "waztreeview", "WAZ", "scrolledwindow4");
 }
 
+void
+notebook_remove_wazpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_remove_awardpage (scorewindow, awardsnotebook, "scrolledwindow4");
+}
+
 void
 notebook_append_iotapage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
 {
 	notebook_append_awardpage (scorewindow, awardsnotebook, "iotatreeview", "IOTA", "scrolledwindow5");
 }
 
+void
+notebook_remove_iotapage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_remove_awardpage (scorewindow, awardsnotebook, "scrolledwindow5");
+}
+
 void
 notebook_append_locpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
 {
 	notebook_append_awardpage (scorewindow, awardsnotebook, "loctreeview", "GRID", "scrolledwindow6");
 }
 
+void
+notebook_remove_locpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_remove_awardpage (scorewindow, awardsnotebook, "scrolledwindow6");
+}
+
 GtkWidget *
 create_scorewindow (void)
 {
