@@ -72,7 +72,7 @@ backuplog (gchar * filename, gchar * backupfilename)
 		{
 			msg = g_strdup_printf (_("Backup to %s failed: %s"),
 				backupfilename, g_strerror (errno));
-			g_warning (msg);
+			g_warning ("%s", msg);
 			g_free (msg);
 		}
 		fclose (in);
