@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -28,26 +28,27 @@
  * NB: Sweepstakes, NAQP and NA Sprint are only supported for import.
  */
 
+#ifndef _XOPEN_SOURCE
+#define _XOPEN_SOURCE
+#endif
 #include <stdlib.h>
-#include <stdio.h>
 #include <string.h>
 #include <locale.h>
 #include <ctype.h>
-#ifndef __USE_XOPEN
-#define __USE_XOPEN
-#endif
+#include <glib/gstdio.h>
 #include <time.h>
 #include <glib.h>
 
 #ifndef HAVE_STRPTIME
-#include "strptime.h"
+#include "../strptime.h"
 #define strptime(s,f,t) mystrptime(s,f,t)
 #endif
 
 #include "logfile.h"
-#include "preferences.h"
-#include "utils.h"
-#include "main.h"
+#include "../cfg.h"
+#include "../utils.h"
+#include "../main.h"
+#include "../xlog_enum.h"
 
 extern preferencestype preferences;
 extern programstatetype programstate;
@@ -91,7 +92,7 @@ cabrillo_open (LOGDB * handle)
 	FILE *fp;
 	static const gint xlog_fields [] = {DATE, GMT, CALL, BAND, MODE, RST, MYRST, AWARDS, REMARKS};
 
-	fp = fopen (handle->path, "r");
+	fp = g_fopen (handle->path, "r");
 	if (!fp)
 		return -1;
 	handle->priv = (gpointer) fp;
@@ -112,7 +113,7 @@ cabrillo_create (LOGDB * handle)
 {
 	FILE *fp;
 
-	fp = fopen (handle->path, "w");
+	fp = g_fopen (handle->path, "w");
 	if (!fp)
 		return -1;
 	handle->priv = (gpointer) fp;
@@ -155,9 +156,8 @@ cabrillo_qso_append (LOGDB * handle, const qso_t * q)
 {
 	FILE *fp = (FILE *) handle->priv;
 	gchar rst[16], exch[16] = "", my_rst[16], my_exch[16] = "", date[16];
-	gchar freq[8];
-	const gchar *mode, *dot;
-	gint rst_len, l;
+	const gchar *mode;
+	gint rst_len;
 	gchar *q_mode = q[MODE] ? q[MODE] : "SSB";
 
 	/*
@@ -181,32 +181,8 @@ cabrillo_qso_append (LOGDB * handle, const qso_t * q)
 		strcpy (my_exch, q[MYRST] + rst_len);
 
 	/* reformat or truncate frequency */
-	if ((dot = strstr (q[BAND], ".")))
-	{
-		l = dot - q[BAND];
-		q[BAND][l] = '\0';
-		sprintf (freq, "%s%s", q[BAND], q[BAND] + l + 1);
-		/* we might have used the optionmenu */
-		if (!strcmp (freq, "18")) strcpy (freq, "1800");
-	}
-	else
-		strncpy (freq, q[BAND], 5);
-	freq[5] = '\0';
-
-	/* we might have used the optionmenu */
-	if (strlen (freq) < 3)
-	{
-		if (!strcmp (freq, "35")) strcpy (freq, "3500");
-		else if (!strcmp (freq, "5")) strcpy (freq, "5300");
-		else if (!strcmp (freq, "7")) strcpy (freq, "7000");
-		else if (!strcmp (freq, "10")) strcpy (freq, "10100");
-		else if (!strcmp (freq, "14")) strcpy (freq, "14000");
-		else if (!strcmp (freq, "18")) strcpy (freq, "18068");
-		else if (!strcmp (freq, "21")) strcpy (freq, "21000");
-		else if (!strcmp (freq, "24")) strcpy (freq, "24890");
-		else if (!strcmp (freq, "28")) strcpy (freq, "28000");
-		else if (!strcmp (freq, "50")) strcpy (freq, "50000");
-	}
+	gint bandenum = freq2enum (q[BAND]);
+	gchar *freq = band_enum2cabrillochar (bandenum);
 
 	/* reshape date */
 	if (strlen (q[DATE]) == 11 && q[DATE][2] == ' ' && q[DATE][6] == ' ')
@@ -239,6 +215,7 @@ cabrillo_qso_append (LOGDB * handle, const qso_t * q)
 	fprintf (fp, "QSO: %5s %-3s%-11s%-5s%-14s%-4s%-7s%-14s%-4s%-7s\n",
 		freq, mode, date, q[GMT],
 		preferences.callsign, rst, exch, q[CALL], my_rst, my_exch);
+	g_free (freq);
 	return 0;
 }
 
