@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -25,13 +25,13 @@
  */
 
 #include <stdlib.h>
-#include <stdio.h>
 #include <string.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 
 #include "logfile.h"
-#include "preferences.h"
-#include "wwl.h"
+#include "../cfg.h"
+#include "../wwl.h"
 
 /*
  * file fields
@@ -56,18 +56,30 @@ const struct log_ops labels_ops = {
 	.extension = ".labels",
 };
 
+typedef struct {
+	FILE *fp;
+	gint groupbycallsign;
+	gchar *prev_call;
+} labels_priv_t;
 /*
  * open for read
  */
 gint
 labels_open (LOGDB * handle)
 {
-	FILE *fp;
+	labels_priv_t *priv;
 
-	fp = fopen (handle->path, "r");
-	if (!fp)
+	priv = g_new0(labels_priv_t, 1);
+	if (!priv)
 		return -1;
-	handle->priv = (gpointer) fp;
+
+	priv->fp = g_fopen (handle->path, "r");
+	if (!priv->fp) {
+		g_free(priv);
+		return -1;
+	}
+	handle->priv = (gpointer) priv;
+	priv->groupbycallsign = preferences.tsvgroupbycallsign;
 
 	return 0;
 }
@@ -78,85 +90,109 @@ labels_open (LOGDB * handle)
 gint
 labels_create (LOGDB * handle)
 {
-	FILE *fp;
+	labels_priv_t *priv;
 
-	fp = fopen (handle->path, "w");
-	if (!fp)
+	priv = g_new0(labels_priv_t, 1);
+	if (!priv)
 		return -1;
-	handle->priv = (gpointer) fp;
+
+	priv->fp = g_fopen (handle->path, "w");
+	if (!priv->fp) {
+		g_free(priv);
+		return -1;
+	}
+	handle->priv = (gpointer) priv;
+	priv->groupbycallsign = preferences.tsvgroupbycallsign;
 	return 0;
 }
 
 void
 labels_close (LOGDB * handle)
 {
-	FILE *fp = (FILE *) handle->priv;
-	fclose (fp);
+	labels_priv_t *priv = (labels_priv_t*)handle->priv;
+	if (priv->prev_call) {
+		g_free(priv->prev_call);
+		priv->prev_call = NULL;
+	}
+	fprintf (priv->fp, "\n");
+	fclose (priv->fp);
+	g_free(priv);
 }
 
 gint
 labels_qso_append (LOGDB * handle, const qso_t * q)
 {
-	FILE *fp = (FILE *) handle->priv;
+	labels_priv_t *priv = (labels_priv_t*)handle->priv;
+	FILE *fp = priv->fp;
 	gint kms, miles, l, result;
 
-	if (preferences.saveastsv2[0] == '1')
+	if (priv->prev_call && (strcmp(q[CALL],priv->prev_call) || --priv->groupbycallsign <= 0)) {
+		fprintf (fp, "\n");
+		priv->groupbycallsign = preferences.tsvgroupbycallsign;
+	}
+	if (priv->prev_call) {
+		g_free(priv->prev_call);
+		priv->prev_call = NULL;
+	}
+	priv->prev_call = g_strdup(q[CALL]);
+
+	if (preferences.saveastsv2[0] == 1)
 	{
 		if (q[DATE]) fprintf (fp, "%s\t", q[DATE]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[2] == '1')
+	if (preferences.saveastsv2[1] == 1)
 	{
 		if (q[GMT]) fprintf (fp, "%s\t", q[GMT]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[4] == '1')
+	if (preferences.saveastsv2[2] == 1)
 	{
 		if (q[GMTEND]) fprintf (fp, "%s\t", q[GMTEND]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[6] == '1')
+	if (preferences.saveastsv2[3] == 1)
 	{
 		if (q[CALL]) fprintf (fp, "%s\t", q[CALL]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[8] == '1')
+	if (preferences.saveastsv2[4] == 1)
 	{
 		if (q[BAND]) fprintf (fp, "%s\t", q[BAND]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[10] == '1')
+	if (preferences.saveastsv2[5] == 1)
 	{
 		if (q[MODE]) fprintf (fp, "%s\t", q[MODE]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[12] == '1')
+	if (preferences.saveastsv2[6] == 1)
 	{
 		if (q[RST]) fprintf (fp, "%s\t", q[RST]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[14] == '1')
+	if (preferences.saveastsv2[7] == 1)
 	{
 		if (q[MYRST]) fprintf (fp, "%s\t", q[MYRST]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[16] == '1')
+	if (preferences.saveastsv2[8] == 1)
 	{
 		if (q[AWARDS]) fprintf (fp, "%s\t", q[AWARDS]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[18] == '1')
+	if (preferences.saveastsv2[9] == 1)
 	{
 		if (q[QSLOUT]) fprintf (fp, "%s\t", q[QSLOUT]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[20] == '1')
+	if (preferences.saveastsv2[10] == 1)
 	{
 		if (q[QSLIN]) fprintf (fp, "%s\t", q[QSLIN]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[22] == '1')
+	if (preferences.saveastsv2[11] == 1)
 	{
 		if (q[POWER]) fprintf (fp, "%s\t", q[POWER]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[24] == '1')
+	if (preferences.saveastsv2[12] == 1)
 	{
 		if (q[NAME]) fprintf (fp, "%s\t", q[NAME]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[26] == '1')
+	if (preferences.saveastsv2[13] == 1)
 	{
 		if (q[QTH]) fprintf (fp, "%s\t", q[QTH]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[28] == '1')
+	if (preferences.saveastsv2[14] == 1)
 	{
 		if (q[LOCATOR])
 		{
@@ -187,19 +223,18 @@ labels_qso_append (LOGDB * handle, const qso_t * q)
 				fprintf (fp, "\t\t\t");
 		}
 	}
-	if (preferences.saveastsv2[30] == '1')
+	if (preferences.saveastsv2[15] == 1)
 	{
 		if (q[U1]) fprintf (fp, "%s\t", q[U1]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[32] == '1')
+	if (preferences.saveastsv2[16] == 1)
 	{
 		if (q[U2]) fprintf (fp, "%s\t", q[U2]); else fprintf (fp, "\t");
 	}
-	if (preferences.saveastsv2[34] == '1')
+	if (preferences.saveastsv2[17] == 1)
 	{
 		if (q[REMARKS]) fprintf (fp, "%s\t", q[REMARKS]); else fprintf (fp, "\t");
 	}
-	fprintf (fp, "\n");
 	return 0;
 }
 
