@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -111,25 +111,25 @@ gint oh1aa_qso_foreach
 //0502201751OK2BMA      59 59  28 MHzSSB pavel                                 0
 
 		/* insert a space between date and time */
-		memmove (buffer+7, buffer+6, MAXROWLEN);
+		memmove (buffer+7, buffer+6, MAXROWLEN-7);
 		buffer[6] = ' ';
 		/* insert a space between time and call */
-		memmove (buffer+12, buffer+11, MAXROWLEN);
+		memmove (buffer+12, buffer+11, MAXROWLEN-12);
 		buffer[11] = ' ';
 		/* insert a space between call and myrst */
-		memmove (buffer+24, buffer+23, MAXROWLEN);
+		memmove (buffer+24, buffer+23, MAXROWLEN-24);
 		buffer[24] = ' ';
 		/* insert a space between myrst and rst */
-		memmove (buffer+28, buffer+27, MAXROWLEN);
+		memmove (buffer+28, buffer+27, MAXROWLEN-28);
 		buffer[28] = ' ';
 		/* insert a space between rst and band */
-		memmove (buffer+32, buffer+31, MAXROWLEN);
+		memmove (buffer+32, buffer+31, MAXROWLEN-32);
 		buffer[32] = ' ';
 		/* insert a space between band and mode */
-		memmove (buffer+40, buffer+39, MAXROWLEN);
+		memmove (buffer+40, buffer+39, MAXROWLEN-40);
 		buffer[40] = ' ';
 		/* insert a space between mode and remarks */
-		memmove (buffer+45, buffer+44, MAXROWLEN);
+		memmove (buffer+45, buffer+44, MAXROWLEN-45);
 		buffer[45] = ' ';
 
 		for (i = 0; i < oh1aa_field_nr; i++)
