@@ -195,7 +195,7 @@ gint trlog_qso_foreach
 			continue;
 
 		/* insert a space between band and mode */
-		memmove (buffer+4, buffer+3, MAXROWLEN);
+		memmove (buffer+4, buffer+3, MAXROWLEN-4);
 		buffer[3] = ' ';
 
 		for (i = 0; i < trlog_field_nr - 1; i++)
