@@ -420,11 +420,11 @@ save_windowsize_and_cleanup (void)
 		gtk_combo_box_get_active (GTK_COMBO_BOX(bandoptionmenu));
 
 	handlebox = lookup_widget (mainwindow, "handlebox");
-	if (GTK_WIDGET_VISIBLE(handlebox))
+	if (gtk_widget_get_visible(handlebox))
 		preferences.viewtoolbar = 1;
 	else
 		preferences.viewtoolbar = 0;
-	if (GTK_WIDGET_VISIBLE(b4window))
+	if (gtk_widget_get_visible(b4window))
 	{
 		preferences.viewb4 = 1;
 		gtk_window_get_size (GTK_WINDOW(b4window),
@@ -440,7 +440,7 @@ save_windowsize_and_cleanup (void)
 		preferences.b4width = 500;
 		preferences.b4height = 300;
 	}
-	if (GTK_WIDGET_VISIBLE(scorewindow))
+	if (gtk_widget_get_visible(scorewindow))
 	{
 		gtk_window_get_size (GTK_WINDOW(scorewindow),
 			&preferences.scorewidth, &preferences.scoreheight);
