@@ -104,7 +104,7 @@ gchar *band_enum2cabrillochar (guint band_enum)
 	return NULL;
 }
 
-gchar *band_enum2bandchar (guint band_enum)
+gchar *band_enum2bandchar (gint band_enum)
 {
 	switch (band_enum)
 	{
@@ -138,8 +138,7 @@ gchar *band_enum2bandchar (guint band_enum)
 		case BAND_1MM: return g_strdup ("1mm");
 		case BAND_SUBMM: return g_strdup ("SUBmm");
 	}
-	return NULL;
-
+	return g_strdup ("??");
 }
 
 /* return band as enum from a given frequency string */
