@@ -98,7 +98,7 @@ gchar *band_enum2char (guint band_enum);
 gchar *band_enum2cabrillochar (guint band_enum);
 gint freq2enum (gchar * str);
 gint hamlibfreq2enum (long long f);
-gchar *band_enum2bandchar (guint band_enum);
+gchar *band_enum2bandchar (gint band_enum);
 gint meters2enum (gchar * str);
 gchar *mode_enum2char (guint mode_enum);
 gint reportlen(guint mode_enum);
